<?php
// ╔═════════════════════════════════════════════════════════════════════════════════════════╗
// ║ Card                                                                                    ║
// ║                                                                                         ║
// ║ @param  string       $class         Extra classes for card element                      ║
// ║ @param  bool         $responsive    (true) If false, this will stop responsive styles.  ║
// ║ @param  string|date  $thumb         Either an image url, or date object                 ║
// ║ @param  string       $download      If a download link, set to file type such as        ║
// ║ @param  string       $heading                                                           ║
// ║ @param  assoc array  $subheadings   Items below header with generated classes           ║
// ║                                     archive, audio, code, excel, image, pdf, powerpoint,║
// ║                                     text, video, word, or '' for empty icon.            ║
// ║ @param  string       $contentImage  Image html to go within .card__content              ║
// ║ @param  string       $content       Any unescaped html content                          ║
// ║ @param  string       $social        Pass HTML for social links - perhaps via an element ║
// ╚═════════════════════════════════════════════════════════════════════════════════════════╝
?>
<?php
	// Build up the .card classes
	if (empty($class)) $class = '';
	$class .= ' card';
	if (isset($responsive) &&
		$responsive == false)  $class .= ' card--nonresponsive';
	if (!empty($thumb))        $class .= ' card--has-thumb';
	if (isset($download))      $class .= ' card--has-thumb card--download card--download--' . $download;
?>
<div class="<?= $class; ?>">
	<?php
		if (!empty($download)) $thumb = true;

		// If has a typical thumb
		if (!empty($thumb)):
			echo '<div class="card__thumb">';

			// Create thumb HTML
			$thumbHtml = '';

			// Thumb image
			if (is_string($thumb)):
				$thumbHtml .= $this->Html->image($thumb, [
					'alt' => '', // typically unnecessary
					'width' => 180,
					'height' => 180,
					'class' => 'card__thumb__image',
				]);

			// Thumb date
			elseif (!is_bool($thumb)):
				$thumbHtml .= '<div class="card__thumb__date">';
				$thumbHtml .= '<span>'.Date('d', $thumb).'</span> ';
				$thumbHtml .= '<span>'.strtoupper(Date('M', $thumb)).'</span>';
				$thumbHtml .= '</div>';
			endif;

			// Thumb download file type
			if (isset($download)):
				$thumbHtml .= '<div class="card__thumb__icon">';
				if ($download == ''):
					$thumbHtml .= '<i class="fa fa-file-o"></i>';
				else:
					$thumbHtml .= '<i class="fa fa-file-'.$download.'-o"></i>';
				endif;
				$thumbHtml .= '</div>';
			endif;

			// echo thumb as a link if provided
			if (!empty($url)):
				echo $this->Html->link(
					$thumbHtml,
					$url,
					['escape' => false]
				);
			// echo thumb without a link
			else:
				echo '<span>' . $thumbHtml . '</span>';
			endif;

			echo '</div>';
		endif;
	?>
	<div class="card__content">
		<div class="wysiwyg">
			<?php if (!empty($contentImage)): ?>
				<div class="card__content__image">
					<?= $contentImage; ?>
				</div>
			<?php endif; ?>

			<?php if (!empty($heading)): ?>
				<div class="card__title">
					<?php
						if (!empty($url)):
							echo $this->Html->link(
								$heading,
								$url
							);
						else:
							echo $heading;
						endif;
					?>
				</div>
			<?php endif; ?>

			<?php if (!empty($subheadings)): ?>
				<div class="card__subheadings">
					<?php
						/**
						 * Subheading elements
						 * Create lovely little spans with predictable classnames, e.g.
						 * .card__subheading.card__subheading--date
						 **/
						foreach ($subheadings as $key => $val):
							echo '<span class="card__subheading card__subheading--' . InflectorExt::snake($key) . '">';
								switch ($key):
									case "date":
										echo Date("d/m/Y", $val);
										break;
									default;
										echo $val;
										break;
								endswitch;
							echo '</span>';
						endforeach;
					?>
				</div>
			<?php endif; ?>

			<?php if (!empty($content)): ?>
				<?= $content; ?>
			<?php endif; ?>
		</div>

		<?php if (!empty($social)): ?>
			<?= $social; ?>
		<?php endif; ?>
	</div>
</div>
